@@ -25,11 +25,6 @@ class LocationSetCollection:
 
     @property
     def hoofd_loc(self) -> HoofdLocationSet:
-        """Get HoofdLocationSet. The property .geo_df has eventually been updated."""
-        if self._hoofd_loc_new is not None:
-            assert self._hoofd_loc and isinstance(self._hoofd_loc, HoofdLocationSet)
-            assert isinstance(self._hoofd_loc_new, pd.DataFrame)
-            self._hoofd_loc._geo_df = self._hoofd_loc_new
         if self._hoofd_loc is not None:
             return self._hoofd_loc
         self._hoofd_loc = HoofdLocationSet(fews_config=self.fews_config)
