@@ -10,12 +10,12 @@ class SubLocTypeChoices(Enum):
     totaal = "totaal"
     vispassage = "vispassage"
     schuif = "schuif"
-    debietmeter = "debietmeter"  # TODO: debietmeter can also be a hoofdlocatie..
+    debietmeter = "debietmeter"  # TODO: debietmeter can also be a hoofd_loc...
     overlaat = "overlaat"
     afsluiter = "afsluiter"
 
     @classmethod
-    def is_a_subloc(cls, value: str):
+    def is_a_sub_loc(cls, value: str):
         return value in {cls.__members__.values()}
 
 
@@ -39,34 +39,14 @@ class SubLocationSet(LocationSetBase):
     @property
     def validation_rules(self):
         return [
-            {
-                "parameter": "H.R.",
-                "extreme_values": {"hmax": "HR1_HMAX", "hmin": "HR1_HMIN"},
-            },
-            {
-                "parameter": "H2.R.",
-                "extreme_values": {"hmax": "HR2_HMAX", "hmin": "HR2_HMIN"},
-            },
-            {
-                "parameter": "H3.R.",
-                "extreme_values": {"hmax": "HR3_HMAX", "hmin": "HR3_HMIN"},
-            },
-            {
-                "parameter": "F.",
-                "extreme_values": {"hmax": "FRQ_HMAX", "hmin": "FRQ_HMIN"},
-            },
-            {
-                "parameter": "Hh.",
-                "extreme_values": {"hmax": "HEF_HMAX", "hmin": "HEF_HMIN"},
-            },
+            {"parameter": "H.R.", "extreme_values": {"hmax": "HR1_HMAX", "hmin": "HR1_HMIN"},},
+            {"parameter": "H2.R.", "extreme_values": {"hmax": "HR2_HMAX", "hmin": "HR2_HMIN"},},
+            {"parameter": "H3.R.", "extreme_values": {"hmax": "HR3_HMAX", "hmin": "HR3_HMIN"},},
+            {"parameter": "F.", "extreme_values": {"hmax": "FRQ_HMAX", "hmin": "FRQ_HMIN"},},
+            {"parameter": "Hh.", "extreme_values": {"hmax": "HEF_HMAX", "hmin": "HEF_HMIN"},},
             {
                 "parameter": "POS.",
-                "extreme_values": {
-                    "hmax": "PERC_HMAX",
-                    "smax": "PERC_SMAX",
-                    "smin": "PERC_SMIN",
-                    "hmin": "PERC_HMIN",
-                },
+                "extreme_values": {"hmax": "PERC_HMAX", "smax": "PERC_SMAX", "smin": "PERC_SMIN", "hmin": "PERC_HMIN",},
             },
             {
                 "parameter": "POS2.",
@@ -77,21 +57,13 @@ class SubLocationSet(LocationSetBase):
                     "hmin": "PERC2_HMIN",
                 },
             },
-            {
-                "parameter": "TT.",
-                "extreme_values": {"hmax": "TT_HMAX", "hmin": "TT_HMIN"},
-            },
+            {"parameter": "TT.", "extreme_values": {"hmax": "TT_HMAX", "hmin": "TT_HMIN"},},
             # HDSR does not yet have validation CSVs for berekend debiet
             # {"parameter": "Q.B.",
             #  "extreme_values": {"hmax": "Q_HMAX", "smax": "Q_SMAX", "smin": "Q_SMIN", "hmin": "Q_HMIN"}},
             {
                 "parameter": "Q.G.",
-                "extreme_values": {
-                    "hmax": "Q_HMAX",
-                    "smax": "Q_SMAX",
-                    "smin": "Q_SMIN",
-                    "hmin": "Q_HMIN",
-                },
+                "extreme_values": {"hmax": "Q_HMAX", "smax": "Q_SMAX", "smin": "Q_SMIN", "hmin": "Q_HMIN",},
             },
             # TODO: I added krooshek below (see H.G.) as it was missing, but krooshek validation csv has:
             #   - 3 soft min: HW_SMIN, HO_SMIN, HZ_SMIN
@@ -105,11 +77,6 @@ class SubLocationSet(LocationSetBase):
             #  {"internal": "H.G.", "external": "HO."}, --> moet bij krooshek
             {
                 "parameter": "H.G.",
-                "extreme_values": {
-                    "hmax": "H_HMAX",
-                    "smax": "HW_SMAX",
-                    "smin": "HW_SMIN",
-                    "hmin": "H_HMIN",
-                },
+                "extreme_values": {"hmax": "H_HMAX", "smax": "HW_SMAX", "smin": "HW_SMIN", "hmin": "H_HMIN",},
             },
         ]
