@@ -8,7 +8,7 @@ from typing import Optional
 import geopandas as gpd
 import logging
 import os
-import pandas as pd  # noqa
+import pandas as pd  # noqa pandas comes with geopandas
 
 
 logger = logging.getLogger(__name__)
@@ -16,6 +16,7 @@ logger = logging.getLogger(__name__)
 
 class FewsConfigReader:
 
+    xyz_columns = {"x": "X", "y": "Y", "z": ""}
     geo_datum = {"Rijks Driehoekstelsel": "epsg:28992"}
     Z_NODATA_VALUE = -9999
 
@@ -240,16 +241,27 @@ class FewsConfigReader:
         filepath = self.path / "MapLayerFiles" / file
 
         assert filepath.is_file(), f"file {filepath} does not exist"
-        gdf = gpd.read_file(filename=filepath)
+        gdf_loc_set = self.get_gdf_locset_via_path(file_path=filepath, xyz_columns={}, location_set=location_set)
+        return gdf_loc_set
 
-        x_column = location_set["csvFile"]["x"].replace("%", "")
-        y_column = location_set["csvFile"]["y"].replace("%", "")
+    @classmethod
+    def get_gdf_locset_via_path(
+        cls, file_path: Path, location_set: Dict = None, xyz_columns: Dict = None
+    ) -> gpd.GeoDataFrame:
+        xyz_columns = xyz_columns if xyz_columns else cls.xyz_columns
+        gdf_location_set = gpd.read_file(filename=file_path)
+        x_column = location_set["csvFile"]["x"].replace("%", "") if location_set else xyz_columns["x"]
+        assert x_column and isinstance(x_column, str)
+        y_column = location_set["csvFile"]["y"].replace("%", "") if location_set else xyz_columns["y"]
+        assert y_column and isinstance(y_column, str)
         # z column does not always exist
-        z_column = location_set["csvFile"].get("z", "").replace("%", "")
-        gdf = self.__add_geometry_column(
-            gdf=gdf, filepath=filepath, x_column=x_column, y_column=y_column, z_column=z_column,
+        z_column = location_set["csvFile"].get("z", "").replace("%", "") if location_set else xyz_columns.get("z", "")
+        assert isinstance(z_column, str)
+
+        gdf_location_set = cls.__add_geometry_column(
+            gdf=gdf_location_set, filepath=file_path, x_column=x_column, y_column=y_column, z_column=z_column,
         )
-        geo_datum_found = location_set["csvFile"]["geoDatum"]
-        crs = self.geo_datum.get(geo_datum_found, None)
-        gdf.crs = crs if crs else None
-        return gdf
+        geo_datum_found = location_set["csvFile"]["geoDatum"] if location_set else ""
+        crs = cls.geo_datum.get(geo_datum_found, None)
+        gdf_location_set.crs = crs if crs else None
+        return gdf_location_set
