@@ -28,11 +28,11 @@ def test_loc_set_columns(loc_sets):
     ]
     for col_name in expected_hoofd_cols:
         if LocSetSharedCols.must_exist(col_name=col_name):
-            assert col_name in loc_sets.hoofd_loc.geo_df.columns
+            assert col_name in loc_sets.hoofd_loc.geo_df_original.columns
 
     # test must_exists cols (in all location sets)
     for loc_set in loc_sets.all():
-        existing_cols = loc_set.geo_df.columns
+        existing_cols = loc_set.geo_df_original.columns
         for col in LocSetSharedCols.get_all():
             if LocSetSharedCols.must_exist(col_name=col):
                 assert col in existing_cols
